@@ -6,17 +6,20 @@ class random_timeout:
     '''Random timeout between from and to values'''
     def __init__(self, from_seconds=None, to_seconds=None, from_minutes=None, to_minutes=None, from_hours=None, to_hours=None, from_days=None, to_days=None):
         if from_seconds is not None:
-            if from_seconds <= 0:
+            if from_seconds == 0:
                 minimum = random()
-            else:
+            elif from_seconds > 1:
                 minimum = from_seconds - random() # Random float between 0 and 1
+            else:
+                minimum = from_seconds
             if to_seconds:
                 maximum = to_seconds
+                if to_seconds > 1:
+                    maximum += random()
             else:
                 maximum = from_seconds
-            maximum += random()
         elif from_minutes is not None:
-            if from_minutes <= 0:
+            if from_minutes == 0:
                 minimum = random()
             else:
                 minimum = (from_minutes - random()) * 60 # Random float between 0 and 1
@@ -25,7 +28,7 @@ class random_timeout:
             else:
                 maximum = from_minutes + random()
         elif from_hours is not None:
-            if from_hours <= 0:
+            if from_hours == 0:
                 minimum = random()
             else:
                 minimum = (from_hours - random()) * 3600 # Random float between 0 and 1
@@ -34,7 +37,7 @@ class random_timeout:
             else:
                 maximum = from_hours + random()
         elif from_days is not None:
-            if from_days <= 0:
+            if from_days == 0:
                 minimum = random()
             else:
                 minimum = (from_days - random()) * 86400 # Random float between 0 and 1
